pub fn detect() -> AppearanceExpand description
Best-effort current OS appearance.
Never panics, never blocks for more than a short subprocess call on macOS / Linux, never touches the filesystem outside the OS-provided settings store.
pub fn detect() -> AppearanceBest-effort current OS appearance.
Never panics, never blocks for more than a short subprocess call on macOS / Linux, never touches the filesystem outside the OS-provided settings store.